@@ -235,8 +235,8 @@ class LocatorMethods(WindowsContext):
     """Keywords for finding Windows GUI elements"""
 
     def __init__(self, ctx, locators_path: Optional[str] = None):
-        self._locators_path = locators_path
         super().__init__(ctx)
+        self._locators_path = locators_path
 
     @staticmethod
     def _get_control_from_params(
@@ -307,32 +307,37 @@ class LocatorMethods(WindowsContext):
 
         return criteria
 
+    def _resolve_root(self, root_element: Optional[WindowsElement]) -> WindowsElement:
+        # Explicit root element > set anchor > active window > Desktop.
+        root = (
+            self._window_or_none(root_element)
+            or self.anchor
+            or self.window
+            or WindowsElement(auto.GetRootControl(), None)
+        )
+        self.logger.info("Resulted root element: %s", root)
+        return root
+
     def _get_element_by_locator_string(
         self, locator: str, search_depth: int, root_element: Optional[WindowsElement]
     ) -> WindowsElement:
-        root = root_element.item if self._window_or_none(root_element) else None
-        anchor = self.anchor.item if self.anchor else None
-        window = self.window.item if self.window else None
-        self.logger.debug("argument root = %s", root)
-        self.logger.debug("active anchor = %s", anchor)
-        self.logger.debug("active window = %s", window)
-        root_result = root or anchor or window or auto.GetRootControl()
-        self.logger.debug("resulting root = %s", root_result)
+        root_control = self._resolve_root(root_element).item
+        locator_parts = locator.split(MatchObject.TREE_SEP)
+        assert locator_parts, "empty locator"
 
-        locators = locator.split(MatchObject.TREE_SEP)
         try:
-            for loc in locators:
-                self.logger.info("Root element: %r", root_result)
+            for locator_part in locator_parts:
+                self.logger.debug("Active root element: %r", root_control)
                 control = self._get_control_with_locator_part(
-                    loc, search_depth, root_result
+                    locator_part, search_depth, root_control
                 )
-                root_result = control
+                root_control = control
         except LookupError as err:
             raise ElementNotFound(
                 f"Element not found with locator {locator!r}"
             ) from err
 
-        # If we get here, then we have a `control` no matter what.
+        # If we get here, a `control` item was found.
         return WindowsElement(control, locator)
 
     @method
@@ -348,11 +353,7 @@ class LocatorMethods(WindowsContext):
             locator = self._load_by_alias(locator)
         self.logger.info("Getting element with locator: %s", locator)
         if not locator:
-            element = (
-                self.ctx.anchor_element
-                or self.ctx.window_element
-                or WindowsElement(auto.GetRootControl(), None)
-            )
+            return self._resolve_root(root_element)
         elif isinstance(locator, str):
             element = self._get_element_by_locator_string(
                 locator, search_depth, root_element
